use serde::{Deserialize, Serialize};
use serde_json;
use std::io::{Error, ErrorKind};

use crate::fs;

#[derive(Debug, Serialize, Deserialize)]
pub struct Post {
    pub id: String,
    pub title: String,
    pub body: String,
    pub date: String,
}

impl Post {
    pub async fn save(&mut self) -> Result<(), Error> {
        fs::write_post_to_disk(self)
    }

    pub fn from_str(blob: &str) -> Result<Post, Error> {
        let mut post: Post = match serde_json::from_str(blob) {
            Ok(p) => Ok(p),
            Err(_) => Err(Error::new(
                ErrorKind::Other,
                format!("Error deserializing post"),
            )),
        }?;
        post.body = post.body.replace("\n", "<br>");
        Ok(post)
    }
}
